@@ -71,8 +71,7 @@ cb_style_combo_changed (
         RsttoGnomeWallpaperManager *manager);
 
 static void
-configure_monitor_chooser_pixbuf (
-    RsttoGnomeWallpaperManager *manager );
+configure_monitor_chooser_pixbuf (RsttoGnomeWallpaperManager *manager);
 
 static GObjectClass *parent_class = NULL;
 
@@ -81,7 +80,7 @@ static RsttoWallpaperManager *gnome_wallpaper_manager_object = NULL;
 struct _RsttoGnomeWallpaperManagerPriv
 {
     gint screen;
-    gint    monitor;
+    gint monitor;
     enum MonitorStyle style;
 
     RsttoFile *file;
@@ -102,7 +101,8 @@ enum
 static gint 
 rstto_gnome_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
-        RsttoFile *file)
+        RsttoFile *file,
+        GtkWindow *parent)
 {
     RsttoGnomeWallpaperManager *manager = RSTTO_GNOME_WALLPAPER_MANAGER (self);
     gint response = GTK_RESPONSE_OK;
@@ -114,13 +114,14 @@ rstto_gnome_wallpaper_manager_configure_dialog_run (
     }
 
     manager->priv->pixbuf = gdk_pixbuf_new_from_file_at_size (
-            rstto_file_get_path(file),
+            rstto_file_get_path (file),
             500,
             500,
             NULL);
 
     configure_monitor_chooser_pixbuf (manager);
 
+    gtk_window_set_transient_for (GTK_WINDOW (manager->priv->dialog), parent);
     response = gtk_dialog_run (GTK_DIALOG (manager->priv->dialog));
     gtk_widget_hide (manager->priv->dialog);
     if ((response == GTK_RESPONSE_OK) || (response == GTK_RESPONSE_APPLY))
@@ -219,41 +220,40 @@ static void
 rstto_gnome_wallpaper_manager_init (GObject *object)
 {
     RsttoGnomeWallpaperManager *manager = RSTTO_GNOME_WALLPAPER_MANAGER (object);
-    GtkWidget *image_prop_table = gtk_table_new (3, 2, FALSE);
-    GtkWidget *style_label = gtk_label_new( _("Style:"));
+    GtkWidget *image_prop_grid = gtk_grid_new ();
+    GtkWidget *style_label = gtk_label_new (_("Style:"));
     GtkWidget *vbox;
+    GtkWidget *button;
 
-    GdkScreen *screen = gdk_screen_get_default ();
-    gint n_monitors = gdk_screen_get_n_monitors (screen);
+    GdkDisplay *display = gdk_display_get_default ();
+    gint n_monitors = gdk_display_get_n_monitors (display);
     GdkRectangle monitor_geometry;
     gint i;
 
     manager->priv = g_new0 (RsttoGnomeWallpaperManagerPriv, 1);
 
-    manager->priv->dialog = gtk_dialog_new_with_buttons (
-            _("Set as wallpaper"),
-            NULL,
-            0,
-            _("_Cancel"),
-            GTK_RESPONSE_CANCEL,
-            _("_Apply"),
-            GTK_RESPONSE_APPLY,
-            _("_OK"),
-            GTK_RESPONSE_OK,
-            NULL);
+    manager->priv->dialog = gtk_dialog_new ();
+    gtk_window_set_title (GTK_WINDOW (manager->priv->dialog), _("Set as wallpaper"));
 
-    vbox = gtk_dialog_get_content_area ( GTK_DIALOG (manager->priv->dialog));
+    button = xfce_gtk_button_new_mixed ("gtk-cancel", _("_Cancel"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_CANCEL);
+    gtk_widget_show (button);
+    button = xfce_gtk_button_new_mixed ("gtk-apply", _("_Apply"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_APPLY);
+    gtk_widget_show (button);
+    button = xfce_gtk_button_new_mixed ("gtk-ok", _("_OK"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_OK);
+    gtk_widget_show (button);
+
+    vbox = gtk_dialog_get_content_area (GTK_DIALOG (manager->priv->dialog));
 
     manager->priv->monitor_chooser = rstto_monitor_chooser_new ();
     manager->priv->style_combo = gtk_combo_box_text_new ();
 
-    gtk_table_set_row_spacing (GTK_TABLE(image_prop_table), 1, 4);
-
     for (i = 0; i < n_monitors; ++i)
     {
-        gdk_screen_get_monitor_geometry (
-                screen,
-                i,
+        gdk_monitor_get_geometry (
+                gdk_display_get_monitor (display, i),
                 &monitor_geometry);
         rstto_monitor_chooser_add (
                 RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
@@ -268,34 +268,27 @@ rstto_gnome_wallpaper_manager_init (GObject *object)
             0);
     gtk_box_pack_start (
             GTK_BOX (vbox),
-            image_prop_table,
+            image_prop_grid,
             FALSE,
             FALSE,
             0);
 
-    gtk_table_attach (
-            GTK_TABLE (image_prop_table),
+    gtk_grid_attach (
+            GTK_GRID (image_prop_grid),
             style_label,
             0,
-            1,
             0,
             1,
-            0,
-            0,
-            0,
-            0);
-    gtk_table_attach (
-            GTK_TABLE (image_prop_table),
+            1);
+    gtk_grid_attach (
+            GTK_GRID (image_prop_grid),
             manager->priv->style_combo,
             1,
-            2,
             0,
             1,
-            GTK_EXPAND|GTK_FILL,
-            0,
-            0,
-            0);
+            1);
 
+    gtk_widget_set_hexpand (manager->priv->style_combo, TRUE);
     gtk_combo_box_text_append_text (
             GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Auto"));
@@ -304,7 +297,8 @@ rstto_gnome_wallpaper_manager_init (GObject *object)
             GTK_COMBO_BOX (manager->priv->style_combo),
             0);
 
-    manager->priv->screen = gdk_screen_get_number (screen);
+    // there's only one screen in GTK3
+    manager->priv->screen = 0;
 
     gtk_window_set_resizable (GTK_WINDOW (manager->priv->dialog), FALSE);
 
