@@ -62,13 +62,15 @@ rstto_monitor_chooser_finalize(GObject *object);
 static void
 rstto_monitor_chooser_realize(GtkWidget *widget);
 static void
-rstto_monitor_chooser_size_request(GtkWidget *, GtkRequisition *);
+rstto_monitor_chooser_get_preferred_width(GtkWidget *, gint *, gint *);
+static void
+rstto_monitor_chooser_get_preferred_height(GtkWidget *, gint *, gint *);
 static void
 rstto_monitor_chooser_size_allocate(GtkWidget *, GtkAllocation *);
 static gboolean 
-rstto_monitor_chooser_expose(GtkWidget *, GdkEventExpose *);
+rstto_monitor_chooser_draw(GtkWidget *, cairo_t *);
 static gboolean
-rstto_monitor_chooser_paint(GtkWidget *widget);
+rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx);
 
 static void
 cb_rstto_button_press_event (GtkWidget *, GdkEventButton *event);
@@ -126,8 +128,6 @@ rstto_monitor_chooser_init(RsttoMonitorChooser *chooser)
     chooser->priv->selected = -1;
     chooser->priv->monitors = g_new0 (Monitor *, 1);
 
-    gtk_widget_set_double_buffered (GTK_WIDGET(chooser), TRUE);
-
     g_signal_connect(G_OBJECT(chooser), "button-press-event", G_CALLBACK(cb_rstto_button_press_event), NULL);
 
     gtk_widget_set_redraw_on_allocate(GTK_WIDGET(chooser), TRUE);
@@ -146,9 +146,10 @@ rstto_monitor_chooser_class_init(RsttoMonitorChooserClass *chooser_class)
 
     parent_class = g_type_class_peek_parent(chooser_class);
 
-    widget_class->expose_event = rstto_monitor_chooser_expose;
+    widget_class->draw = rstto_monitor_chooser_draw;
     widget_class->realize = rstto_monitor_chooser_realize;
-    widget_class->size_request = rstto_monitor_chooser_size_request;
+    widget_class->get_preferred_width = rstto_monitor_chooser_get_preferred_width;
+    widget_class->get_preferred_height = rstto_monitor_chooser_get_preferred_height;
     widget_class->size_allocate = rstto_monitor_chooser_size_allocate;
 
     object_class->finalize = rstto_monitor_chooser_finalize;
@@ -182,7 +183,6 @@ rstto_monitor_chooser_realize(GtkWidget *widget)
     gint attributes_mask;
     GtkAllocation allocation;
     GdkWindow *window;
-    GtkStyle *style;
 
     g_return_if_fail (widget != NULL);
     g_return_if_fail (RSTTO_IS_MONITOR_CHOOSER (widget));
@@ -199,25 +199,26 @@ rstto_monitor_chooser_realize(GtkWidget *widget)
     attributes.window_type = GDK_WINDOW_CHILD;
     attributes.event_mask = gtk_widget_get_events (widget) | GDK_EXPOSURE_MASK | GDK_BUTTON_PRESS_MASK;
     attributes.visual = gtk_widget_get_visual (widget);
-    attributes.colormap = gtk_widget_get_colormap (widget);
+    // TODO: comment out for now
+    //attributes.colormap = gtk_widget_get_colormap (widget);
 
-    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL | GDK_WA_COLORMAP;
+    // TODO: comment out for now
+    attributes_mask = GDK_WA_X | GDK_WA_Y | GDK_WA_VISUAL /*| GDK_WA_COLORMAP*/;
     window = gdk_window_new (gtk_widget_get_parent_window (widget), &attributes, attributes_mask);
     gtk_widget_set_window (widget, window);
-
-    style = gtk_style_attach (gtk_widget_get_style (widget), window);
-    gtk_widget_set_style (widget, style);
     gdk_window_set_user_data (window, widget);
-
-    gtk_style_set_background (gtk_widget_get_style (widget), window, GTK_STATE_ACTIVE);
 }
 
+static void
+rstto_monitor_chooser_get_preferred_width(GtkWidget *widget, gint *minimal_width, gint *natural_width)
+{
+    *minimal_width = *natural_width = 400;
+}
 
 static void
-rstto_monitor_chooser_size_request(GtkWidget *widget, GtkRequisition *requisition)
+rstto_monitor_chooser_get_preferred_height(GtkWidget *widget, gint *minimal_height, gint *natural_height)
 {
-    requisition->height = 200;
-    requisition->width = 400;
+    *minimal_height = *natural_height = 200;
 }
 
 static void
@@ -235,37 +236,29 @@ rstto_monitor_chooser_size_allocate(GtkWidget *widget, GtkAllocation *allocation
 }
 
 static gboolean
-rstto_monitor_chooser_expose(GtkWidget *widget, GdkEventExpose *event)
+rstto_monitor_chooser_draw(GtkWidget *widget, cairo_t *cr)
 {
-    rstto_monitor_chooser_paint (widget);
+    cairo_save (cr);
+    rstto_monitor_chooser_paint (widget, cr);
+    cairo_restore (cr);
     return FALSE;
 }
 
 static gboolean
-rstto_monitor_chooser_paint(GtkWidget *widget)
+rstto_monitor_chooser_paint(GtkWidget *widget, cairo_t *ctx)
 {
     RsttoMonitorChooser *chooser = RSTTO_MONITOR_CHOOSER (widget);
-    cairo_t *ctx = gdk_cairo_create (gtk_widget_get_window (widget));
     Monitor *monitor;
-    GtkAllocation allocation;
 
     gdouble width, height;
     gchar *label = NULL;
     gint row_width = 0;
     gint id = 0;
+    gdouble alloc_width = (gdouble)gtk_widget_get_allocated_width (widget);
+    gdouble alloc_height = (gdouble)gtk_widget_get_allocated_height (widget);
+    GtkStyleContext *context = gtk_widget_get_style_context (widget);
 
-    gtk_widget_get_allocation (widget, &allocation);
-
-    gdk_cairo_set_source_color (
-            ctx,
-            &(gtk_widget_get_style (widget)->bg[GTK_STATE_NORMAL]));
-    cairo_rectangle (
-            ctx,
-            0.0,
-            0.0,
-            (gdouble)allocation.width,
-            (gdouble)allocation.height);
-    cairo_fill (ctx);
+    gtk_render_background (context, ctx, 0, 0, alloc_width, alloc_height);
 
     if (chooser->priv->n_monitors > 1)
     {
@@ -278,12 +271,12 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
             {
                 if (monitor->width > monitor->height)
                 {
-                    width = allocation.width*0.4;
+                    width = alloc_width*0.4;
                     height = width;
                 } 
                 else
                 {
-                    height = allocation.width*0.4;
+                    height = alloc_width*0.4;
                     width = height;
                 }
                 label = g_strdup_printf("%d", id+1);
@@ -291,8 +284,8 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                 paint_monitor (
                         widget,
                         ctx,
-                        ((gdouble)allocation.width/4) - (width/2.0),
-                        ((gdouble)allocation.height - height)/2.0,
+                        (alloc_width/4) - (width/2.0),
+                        (alloc_height - height)/2.0,
                         width,
                         height,
                         label,
@@ -307,12 +300,12 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
 
                 if (monitor->width > monitor->height)
                 {
-                    width = allocation.width*(0.4/((gdouble)row_width+1));
+                    width = alloc_width*(0.4/((gdouble)row_width+1));
                     height = width;
                 } 
                 else
                 {
-                    height = allocation.width*(0.4/chooser->priv->n_monitors);
+                    height = alloc_width*(0.4/chooser->priv->n_monitors);
                     width = height;
                 }
             
@@ -324,11 +317,11 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                     paint_monitor (
                             widget,
                             ctx,
-                            ((gdouble)allocation.width/2)+
-                                (((gdouble)allocation.width/2)/
+                            (alloc_width/2)+
+                                ((alloc_width/2)/
                                 (row_width+1))*(id%(row_width)+1)-
                                 (width/2.0),
-                            ((gdouble)allocation.height/
+                            (alloc_height/
                                 (row_width+2)*(id/row_width+1))-
                                 (height/2.0),
                             width,
@@ -342,11 +335,11 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
                     paint_monitor (
                             widget,
                             ctx,
-                            ((gdouble)allocation.width/2)+
-                                (((gdouble)allocation.width/2)/
+                            (alloc_width/2)+
+                                ((alloc_width/2)/
                                 (row_width+1))*((id-1)%(row_width)+1)-
                                 (width/2.0),
-                            ((gdouble)allocation.height/
+                            (alloc_height/
                                 (row_width+2)*((id-1)/row_width+1))-
                                 (height/2.0),
                             width,
@@ -379,8 +372,8 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
             paint_monitor (
                     widget,
                     ctx,
-                    ((gdouble)allocation.width - width)/2.0,
-                    ((gdouble)allocation.height - height)/2.0,
+                    (alloc_width - width)/2.0,
+                    (alloc_height - height)/2.0,
                     width,
                     height,
                     "1",
@@ -390,8 +383,6 @@ rstto_monitor_chooser_paint(GtkWidget *widget)
         }
     }
 
-    cairo_destroy (ctx);
-
     return FALSE;
 }
 
@@ -477,15 +468,11 @@ paint_monitor ( GtkWidget *widget,
     cairo_close_path (cr);
 
     /* Fill the background-color */
-    gdk_cairo_set_source_color (
-            cr,
-            &(gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]));
+    cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 1.0); // white
     cairo_fill_preserve (cr);
 
     /* Paint the outside border */
-    gdk_cairo_set_source_color (
-            cr,
-            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
+    cairo_set_source_rgba (cr, 0.231, 0.231, 0.231, 1.0); // dark gray-ish
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -524,13 +511,9 @@ paint_monitor ( GtkWidget *widget,
             monitor_x+(monitor_width-foot_height)/2.0,
             monitor_y+(monitor_height+monitor_border_width+foot_height*0.5));
     cairo_close_path (cr);
-    gdk_cairo_set_source_color (
-            cr,
-            &(gtk_widget_get_style (widget)->base[GTK_STATE_NORMAL]));
+    cairo_set_source_rgba (cr, 1.0, 1.0, 1.0, 1.0); // white
     cairo_fill_preserve (cr);
-    gdk_cairo_set_source_color (
-            cr,
-            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
+    cairo_set_source_rgba (cr, 0.231, 0.231, 0.231, 1.0); // dark gray-ish
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -541,9 +524,7 @@ paint_monitor ( GtkWidget *widget,
     cairo_line_to (cr, monitor_x+monitor_width, monitor_y + monitor_height);
     cairo_line_to (cr, monitor_x, monitor_y + monitor_height);
     cairo_close_path (cr);
-    gdk_cairo_set_source_color (
-            cr,
-            &(gtk_widget_get_style (widget)->fg[GTK_STATE_NORMAL]));
+    cairo_set_source_rgba (cr, 0.231, 0.231, 0.231, 1.0); // dark gray-ish
     cairo_set_line_width (cr, line_width);
     cairo_stroke (cr);
 
@@ -714,7 +695,7 @@ rstto_monitor_chooser_set_image_surface (
     }
     if (gtk_widget_get_realized (GTK_WIDGET (chooser)))
     {
-        rstto_monitor_chooser_paint (GTK_WIDGET (chooser));
+        gtk_widget_queue_draw (GTK_WIDGET (chooser));
     }
 
     return retval;
@@ -777,7 +758,7 @@ cb_rstto_button_press_event (
 
                 g_signal_emit (G_OBJECT (chooser), rstto_monitor_chooser_signals[RSTTO_MONITOR_CHOOSER_SIGNAL_CHANGED], 0, NULL);
 
-                rstto_monitor_chooser_paint (widget);
+                gtk_widget_queue_draw (widget);
             }
         }
 
