@@ -123,50 +123,45 @@ static void
 rstto_properties_dialog_init (RsttoPropertiesDialog *dialog)
 {
     GtkWidget *vbox;
-    GtkWidget *table;
+    GtkWidget *grid;
     /* General tab */
     GtkWidget *general_label;
-    GtkWidget *name_hbox = gtk_hbox_new (FALSE, 4);
-    GtkWidget *name_label = gtk_label_new(NULL);
-    GtkWidget *mime_label = gtk_label_new(NULL);
+    GtkWidget *name_hbox = gtk_box_new (GTK_ORIENTATION_HORIZONTAL, 4);
+    GtkWidget *name_label = gtk_label_new (NULL);
+    GtkWidget *mime_label = gtk_label_new (NULL);
 
-    GtkWidget *modified_label = gtk_label_new(NULL);
-    GtkWidget *accessed_label = gtk_label_new(NULL);
+    GtkWidget *modified_label = gtk_label_new (NULL);
+    GtkWidget *accessed_label = gtk_label_new (NULL);
 
-    GtkWidget *size_label  = gtk_label_new(NULL);
+    GtkWidget *size_label = gtk_label_new (NULL);
+
+    GtkWidget *button = xfce_gtk_button_new_mixed ("window-close", _("_Close"));
 
     dialog->priv = g_new0 (RsttoPropertiesDialogPriv, 1);
 
     dialog->priv->settings = rstto_settings_new ();
     dialog->priv->image_thumbnail = gtk_image_new ();
-    dialog->priv->name_entry = gtk_entry_new();
-    dialog->priv->mime_content_label = gtk_label_new(NULL);
-    dialog->priv->modified_content_label = gtk_label_new(NULL);
-    dialog->priv->accessed_content_label = gtk_label_new(NULL);
-    dialog->priv->size_content_label = gtk_label_new(NULL);
+    dialog->priv->name_entry = gtk_entry_new ();
+    dialog->priv->mime_content_label = gtk_label_new (NULL);
+    dialog->priv->modified_content_label = gtk_label_new (NULL);
+    dialog->priv->accessed_content_label = gtk_label_new (NULL);
+    dialog->priv->size_content_label = gtk_label_new (NULL);
 
-    gtk_misc_set_alignment (
-            GTK_MISC (dialog->priv->mime_content_label),
-            0.0,
-            0.5);
-    gtk_misc_set_alignment (
-            GTK_MISC (dialog->priv->modified_content_label),
-            0.0,
-            0.5);
-    gtk_misc_set_alignment (
-            GTK_MISC (dialog->priv->accessed_content_label),
-            0.0,
-            0.5);
-    gtk_misc_set_alignment (
-            GTK_MISC (dialog->priv->size_content_label),
-            0.0,
-            0.5);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->mime_content_label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->mime_content_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->modified_content_label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->modified_content_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->accessed_content_label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->accessed_content_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (dialog->priv->size_content_label), 0.0);
+    gtk_label_set_yalign (GTK_LABEL (dialog->priv->size_content_label), 0.5);
 
-    vbox = gtk_dialog_get_content_area (
-            GTK_DIALOG (dialog));
+    vbox = gtk_dialog_get_content_area (GTK_DIALOG (dialog));
     dialog->priv->notebook = gtk_notebook_new ();
 
-    table = gtk_table_new (5, 2, FALSE);
+    grid = gtk_grid_new ();
+    gtk_grid_set_column_spacing (GTK_GRID (grid), 4);
+    gtk_grid_set_row_spacing (GTK_GRID (grid), 4);
     gtk_box_pack_start (
             GTK_BOX (name_hbox),
             dialog->priv->image_thumbnail,
@@ -175,138 +170,40 @@ rstto_properties_dialog_init (RsttoPropertiesDialog *dialog)
             GTK_BOX (name_hbox),
             name_label,
             TRUE, TRUE, 0);
-    gtk_label_set_markup (GTK_LABEL(name_label), _("<b>Name:</b>"));
-    gtk_label_set_markup (GTK_LABEL(mime_label), _("<b>Kind:</b>"));
-    gtk_label_set_markup (GTK_LABEL(modified_label), _("<b>Modified:</b>"));
-    gtk_label_set_markup (GTK_LABEL(accessed_label), _("<b>Accessed:</b>"));
-    gtk_label_set_markup (GTK_LABEL(size_label), _("<b>Size:</b>"));
+    gtk_label_set_markup (GTK_LABEL (name_label), _("<b>Name:</b>"));
+    gtk_label_set_markup (GTK_LABEL (mime_label), _("<b>Kind:</b>"));
+    gtk_label_set_markup (GTK_LABEL (modified_label), _("<b>Modified:</b>"));
+    gtk_label_set_markup (GTK_LABEL (accessed_label), _("<b>Accessed:</b>"));
+    gtk_label_set_markup (GTK_LABEL (size_label), _("<b>Size:</b>"));
 
-    gtk_misc_set_alignment (GTK_MISC (name_label), 1.0, 0.5);
-    gtk_misc_set_alignment (GTK_MISC (mime_label), 1.0, 0.5);
-    gtk_misc_set_alignment (GTK_MISC (modified_label), 1.0, 0.5);
-    gtk_misc_set_alignment (GTK_MISC (accessed_label), 1.0, 0.5);
-    gtk_misc_set_alignment (GTK_MISC (size_label), 1.0, 0.5);
+    gtk_label_set_xalign (GTK_LABEL (name_label), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (name_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (mime_label), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (mime_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (modified_label), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (modified_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (accessed_label), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (accessed_label), 0.5);
+    gtk_label_set_xalign (GTK_LABEL (size_label), 1.0);
+    gtk_label_set_yalign (GTK_LABEL (size_label), 0.5);
 
-    gtk_table_attach (
-            GTK_TABLE (table),
-            name_hbox,
-            0,
-            1,
-            0,
-            1,
-            GTK_SHRINK | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-
-    gtk_table_attach (
-            GTK_TABLE (table),
-            dialog->priv->name_entry,
-            1,
-            2,
-            0,
-            1,
-            GTK_EXPAND | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-
-    gtk_table_attach (
-            GTK_TABLE (table),
-            mime_label,
-            0,
-            1,
-            1,
-            2,
-            GTK_SHRINK | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-    gtk_table_attach (
-            GTK_TABLE (table),
-            dialog->priv->mime_content_label,
-            1,
-            2,
-            1,
-            2,
-            GTK_EXPAND | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-
-    gtk_table_attach (
-            GTK_TABLE (table),
-            modified_label,
-            0,
-            1,
-            2,
-            3,
-            GTK_SHRINK | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-    gtk_table_attach (
-            GTK_TABLE (table),
-            dialog->priv->modified_content_label,
-            1,
-            2,
-            2,
-            3,
-            GTK_EXPAND | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-
-    gtk_table_attach (
-            GTK_TABLE (table),
-            accessed_label,
-            0,
-            1,
-            3,
-            4,
-            GTK_SHRINK | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-    gtk_table_attach (
-            GTK_TABLE (table),
-            dialog->priv->accessed_content_label,
-            1,
-            2,
-            3,
-            4,
-            GTK_EXPAND | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-
-    gtk_table_attach (
-            GTK_TABLE (table),
-            size_label,
-            0,
-            1,
-            4,
-            5,
-            GTK_SHRINK | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
-    gtk_table_attach (
-            GTK_TABLE (table),
-            dialog->priv->size_content_label,
-            1,
-            2,
-            4,
-            5,
-            GTK_EXPAND | GTK_FILL,
-            GTK_SHRINK,
-            4,
-            4);
+    gtk_grid_attach (GTK_GRID (grid), name_hbox,                            0, 0, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), dialog->priv->name_entry,             1, 0, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), mime_label,                           0, 1, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), dialog->priv->mime_content_label,     1, 1, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), modified_label,                       0, 2, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), dialog->priv->modified_content_label, 1, 2, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), accessed_label,                       0, 3, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), dialog->priv->accessed_content_label, 1, 3, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), size_label,                           0, 4, 1, 1);
+    gtk_grid_attach (GTK_GRID (grid), dialog->priv->size_content_label,     1, 4, 1, 1);
 
     general_label = gtk_label_new (_("General"));
-    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->priv->notebook), table, general_label);
+    gtk_notebook_append_page (GTK_NOTEBOOK (dialog->priv->notebook), grid, general_label);
 
-    dialog->priv->image_table = gtk_table_new (5, 2, FALSE);
+    dialog->priv->image_table = gtk_grid_new ();
+    gtk_grid_set_column_spacing (GTK_GRID (dialog->priv->image_table), 4);
+    gtk_grid_set_row_spacing (GTK_GRID (dialog->priv->image_table), 4);
     dialog->priv->image_label = gtk_label_new (_("Image"));
 
     gtk_notebook_append_page (
@@ -319,10 +216,10 @@ rstto_properties_dialog_init (RsttoPropertiesDialog *dialog)
     gtk_widget_show_all (vbox);
 
     /* Window should not be resizable */
-    gtk_window_set_resizable(GTK_WINDOW(dialog), FALSE);
+    gtk_window_set_resizable (GTK_WINDOW (dialog), FALSE);
 
-
-    gtk_dialog_add_button (GTK_DIALOG (dialog), _("_Close"), GTK_RESPONSE_OK);
+    gtk_dialog_add_action_widget (GTK_DIALOG (dialog), button, GTK_RESPONSE_OK);
+    gtk_widget_show (button);
 }
 
 static void
@@ -589,42 +486,36 @@ properties_dialog_set_file (
                 gtk_label_set_markup (
                         GTK_LABEL (exif_label),
                         label_string);
-                gtk_misc_set_alignment (
-                        GTK_MISC (exif_label),
-                        1.0,
+                gtk_label_set_xalign (
+                        GTK_LABEL (exif_label),
+                        1.0);
+                gtk_label_set_yalign (
+                        GTK_LABEL (exif_label),
                         0.5);
                 gtk_label_set_text (
                         GTK_LABEL (exif_content_label),
                         exif_data
                         );
 
-                gtk_table_attach (
-                        GTK_TABLE (dialog->priv->image_table),
+                gtk_grid_attach (
+                        GTK_GRID (dialog->priv->image_table),
                         exif_label,
                         0,
-                        1,
                         i,
-                        i+1,
-                        GTK_SHRINK | GTK_FILL,
-                        GTK_SHRINK,
-                        4,
-                        4);
-                gtk_table_attach (
-                        GTK_TABLE (dialog->priv->image_table),
+                        1,
+                        1);
+                gtk_grid_attach (
+                        GTK_GRID (dialog->priv->image_table),
                         exif_content_label,
                         1,
-                        2,
                         i,
-                        i+1,
-                        GTK_EXPAND | GTK_FILL,
-                        GTK_SHRINK,
-                        4,
-                        4);
+                        1,
+                        1);
                 if (NULL != label_string)
                 {
                     g_free (label_string);
                 }
-            }
+           }
 
             gtk_widget_show_all (dialog->priv->image_table);
         }
