@@ -46,7 +46,7 @@ typedef struct _RsttoWallpaperManagerIface RsttoWallpaperManagerIface;
 struct _RsttoWallpaperManagerIface {
     GTypeInterface parent;
 
-    gint (*configure_dialog_run) (RsttoWallpaperManager *self, RsttoFile *file);
+    gint (*configure_dialog_run) (RsttoWallpaperManager *self, RsttoFile *file, GtkWindow *parent);
     gboolean (*set) (RsttoWallpaperManager *self, RsttoFile *file);
     gboolean (*check_running) (RsttoWallpaperManager *self);
 };
@@ -60,7 +60,8 @@ rstto_wallpaper_manager_check_running (RsttoWallpaperManager *self);
 gint
 rstto_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
-        RsttoFile *file);
+        RsttoFile *file,
+        GtkWindow *parent);
 
 gboolean
 rstto_wallpaper_manager_set (
