@@ -24,6 +24,7 @@
 #include <X11/Xlib.h>
 #include <X11/Xatom.h>
 #include <xfconf/xfconf.h>
+#include <libxfce4ui/libxfce4ui.h>
 #include <libxfce4util/libxfce4util.h>
 #include <gio/gio.h>
 
@@ -76,11 +77,6 @@ static void
 configure_monitor_chooser_pixbuf (
     RsttoXfceWallpaperManager *manager );
 
-static gchar *
-get_human_monitor_name (const gchar *prop_name);
-static gchar *
-retrieve_monitor_name (gint monitor_id);
-
 static void
 cb_style_combo_changed (
         GtkComboBox *style_combo,
@@ -124,93 +120,11 @@ enum
     PROP_0,
 };
 
-static gchar *
-get_human_monitor_name (const gchar *prop_name)
-{
-    GRegex *regex;
-    GMatchInfo *info;
-    gchar *res = NULL;
-
-    regex = g_regex_new ("/(?P<monitor>monitor\\D+-\\d+)/", 0, 0, NULL);
-    if (regex != NULL)
-    {
-        if (g_regex_match (regex, prop_name, 0, &info))
-            res = g_match_info_fetch_named (info, "monitor");
-
-        g_match_info_free (info);
-        g_regex_unref (regex);
-    }
-
-    return res;
-}
-
-static gchar *
-retrieve_monitor_name (gint monitor_id)
-{
-    GDBusProxy *proxy;
-    GError *err = NULL;
-    GVariant *variant;
-    GVariantIter *iter;
-    gchar *key, *monitor_name = NULL, *result;
-
-    proxy = g_dbus_proxy_new_for_bus_sync (G_BUS_TYPE_SESSION,
-                                           G_DBUS_PROXY_FLAGS_NONE,
-                                           NULL,
-                                           "org.xfce.Xfconf",
-                                           "/org/xfce/Xfconf",
-                                           "org.xfce.Xfconf",
-                                           NULL, &err);
-    if (proxy == NULL)
-    {
-        g_warning ("Could not get access to the D-Bus interface: %s",
-                   err->message);
-        g_error_free (err);
-    }
-    else
-    {
-        variant = g_dbus_proxy_call_sync (proxy, "GetAllProperties",
-                                          g_variant_new ("(ss)",
-                                                         "xfce4-desktop",
-                                                         "/"),
-                                          G_DBUS_CALL_FLAGS_NONE,
-                                          -1, NULL, &err);
-        if (variant == NULL)
-        {
-            g_warning ("Method failed: %s", err->message);
-            g_error_free (err);
-        }
-        else
-        {
-            g_variant_get (variant, "(a{sv})", &iter);
-            /* Only keys are interesting */
-            while (g_variant_iter_loop (iter, "{&sv}", &key))
-            {
-                //printf("%s\n", key);
-                monitor_name = get_human_monitor_name (key);
-                if (monitor_name)
-                    break;
-            }
-            g_variant_iter_free (iter);
-            g_variant_unref (variant);
-        }
-        g_object_unref (proxy);
-    }
-
-    if (monitor_name)
-    {
-        result = g_strdup (monitor_name);
-        g_free (monitor_name);
-    }
-    else
-        result = g_strdup_printf ("monitor%d", monitor_id);
-
-    return result;
-}
-
 static gint 
 rstto_xfce_wallpaper_manager_configure_dialog_run (
         RsttoWallpaperManager *self,
-        RsttoFile *file)
+        RsttoFile *file,
+        GtkWindow *parent)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
     gint response = 0;
@@ -229,6 +143,7 @@ rstto_xfce_wallpaper_manager_configure_dialog_run (
 
     configure_monitor_chooser_pixbuf (manager);
 
+    gtk_window_set_transient_for (GTK_WINDOW (manager->priv->dialog), parent);
     response = gtk_dialog_run (GTK_DIALOG (manager->priv->dialog));
     gtk_widget_hide (manager->priv->dialog);
     if ((response == GTK_RESPONSE_OK) || (response == GTK_RESPONSE_APPLY))
@@ -249,14 +164,13 @@ rstto_xfce_wallpaper_manager_check_running (RsttoWallpaperManager *self)
 {
     gchar selection_name[100];
     Atom xfce_selection_atom;
-    GdkScreen *gdk_screen = gdk_screen_get_default();
-    gint xscreen = gdk_screen_get_number(gdk_screen);
-    Display *gdk_display = gdk_x11_get_default_xdisplay();
+    gint xscreen = 0;
+    Display *gdk_display = gdk_x11_get_default_xdisplay ();
 
-    g_snprintf(selection_name, 100, XFDESKTOP_SELECTION_FMT, xscreen);
+    g_snprintf (selection_name, 100, XFDESKTOP_SELECTION_FMT, xscreen);
 
     xfce_selection_atom = XInternAtom (gdk_display, selection_name, False);
-    if((XGetSelectionOwner(gdk_display, xfce_selection_atom)))
+    if ((XGetSelectionOwner (gdk_display, xfce_selection_atom)))
     {
         return TRUE;
     }
@@ -269,80 +183,56 @@ rstto_xfce_wallpaper_manager_set (RsttoWallpaperManager *self, RsttoFile *file)
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (self);
 
     const gchar *uri = rstto_file_get_path (file);
+    GdkDisplay *display = gdk_display_get_default ();
+    GdkScreen *gdk_screen = gdk_display_get_default_screen (display);
+    const gint workspace_nr = rstto_get_active_workspace_number (gdk_screen);
+    const gchar *monitor_name = gdk_monitor_get_model (gdk_display_get_monitor (display, manager->priv->monitor));
 
-    GdkDisplay *display;
-    GdkScreen *gdk_screen;
-    gint workspace_nr;
-    gchar *monitor_name;
     gchar *image_path_prop;
     gchar *image_style_prop;
-
-    display = gdk_display_get_default ();
-    gdk_screen = gdk_display_get_screen (display,
-            manager->priv->screen);
-
-    workspace_nr = rstto_get_active_workspace_number (gdk_screen);
-
-    monitor_name = gdk_screen_get_monitor_plug_name (gdk_screen,
-            manager->priv->monitor);
+    gchar *monitor_prop;
+    GHashTable *props;
 
     /* New properties since xfdesktop >= 4.11 */
     if (monitor_name)
     {
-        image_path_prop = g_strdup_printf (
-                "/backdrop/screen%d/monitor%s/workspace%d/last-image",
-                manager->priv->screen,
-                monitor_name,
-                workspace_nr);
+        image_path_prop = g_strdup_printf ("/backdrop/screen%d/monitor%s/workspace%d/last-image",
+                                           manager->priv->screen, monitor_name, workspace_nr);
+        image_style_prop = g_strdup_printf ("/backdrop/screen%d/monitor%s/workspace%d/image-style",
+                                            manager->priv->screen, monitor_name, workspace_nr);
 
-        image_style_prop = g_strdup_printf (
-                "/backdrop/screen%d/monitor%s/workspace%d/image-style",
-                manager->priv->screen,
-                monitor_name,
-                workspace_nr);
+        xfconf_channel_set_string (manager->priv->channel, image_path_prop, uri);
+        xfconf_channel_set_int (manager->priv->channel, image_style_prop, manager->priv->style);
+
+        g_free (image_path_prop);
+        g_free (image_style_prop);
     }
-    else
+
+    /* Support for xfdesktop < 4.13 (gtk2) */
+    monitor_prop = g_strdup_printf ("/backdrop/screen%d/monitor%d",
+                                    manager->priv->screen, manager->priv->monitor);
+    if ((props = xfconf_channel_get_properties (manager->priv->channel, monitor_prop)) != NULL)
     {
-        /* gdk_screen_get_monitor_plug_name can return NULL */
-        monitor_name = retrieve_monitor_name (manager->priv->monitor);
-        printf("%d %s\n", manager->priv->monitor, monitor_name);
+        image_path_prop = g_strdup_printf ("/backdrop/screen%d/monitor%d/workspace%d/last-image",
+                                           manager->priv->screen, manager->priv->monitor, workspace_nr);
+        image_style_prop = g_strdup_printf ("/backdrop/screen%d/monitor%d/workspace%d/image-style",
+                                            manager->priv->screen, manager->priv->monitor, workspace_nr);
 
-        /*image_path_prop = g_strdup_printf (
-                "/backdrop/screen%d/%s/workspace%d/last-image",
-                manager->priv->screen,
-                monitor_name,
-                workspace_nr);
+        xfconf_channel_set_string (manager->priv->channel, image_path_prop, uri);
+        xfconf_channel_set_int (manager->priv->channel, image_style_prop, manager->priv->style);
 
-        image_style_prop = g_strdup_printf (
-                "/backdrop/screen%d/%s/workspace%d/image-style",
-                manager->priv->screen,
-                monitor_name,
-                workspace_nr);*/
-
-        g_free (monitor_name);
+        g_free (image_path_prop);
+        g_free (image_style_prop);
+        g_hash_table_unref (props);
     }
 
-
-    xfconf_channel_set_string (
-            manager->priv->channel,
-            image_path_prop,
-            uri);
     /* Don't force to add 'single-workspace-mode' property */
-    if (xfconf_channel_has_property (manager->priv->channel,
-            SINGLE_WORKSPACE_MODE))
+    if (xfconf_channel_has_property (manager->priv->channel, SINGLE_WORKSPACE_MODE))
     {
-        xfconf_channel_set_bool (
-                manager->priv->channel,
-                SINGLE_WORKSPACE_MODE,
-                manager->priv->workspace_mode);
+        xfconf_channel_set_bool (manager->priv->channel, SINGLE_WORKSPACE_MODE, manager->priv->workspace_mode);
     }
-    xfconf_channel_set_int (
-            manager->priv->channel,
-            image_style_prop,
-            manager->priv->style);
 
-    g_free (image_path_prop);
-    g_free (image_style_prop);
+    g_free (monitor_prop);
 
     return FALSE;
 }
@@ -404,12 +294,13 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
 {
     RsttoXfceWallpaperManager *manager = RSTTO_XFCE_WALLPAPER_MANAGER (object);
     gint i;
-    GdkScreen *screen = gdk_screen_get_default ();
-    gint n_monitors = gdk_screen_get_n_monitors (screen);
+    GdkDisplay *display = gdk_display_get_default ();
+    gint n_monitors = gdk_display_get_n_monitors (display);
     GdkRectangle monitor_geometry;
     GtkWidget *vbox;
+    GtkWidget *button;
     GtkWidget *style_label = gtk_label_new (_("Style:"));
-    GtkWidget *image_prop_table = gtk_table_new (2, 2, FALSE);
+    GtkWidget *image_prop_grid = gtk_grid_new ();
 
     manager->priv = g_new0(RsttoXfceWallpaperManagerPriv, 1);
     manager->priv->channel = xfconf_channel_new ("xfce4-desktop");
@@ -425,30 +316,31 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             SINGLE_WORKSPACE_MODE,
             TRUE);
 
-    manager->priv->dialog = gtk_dialog_new_with_buttons (
-            _("Set as wallpaper"),
-            NULL,
-            0,
-            _("_Cancel"),
-            GTK_RESPONSE_CANCEL,
-            _("_Apply"),
-            GTK_RESPONSE_APPLY,
-            _("_OK"),
-            GTK_RESPONSE_OK,
-            NULL);
+    manager->priv->dialog = gtk_dialog_new ();
+    gtk_window_set_title (GTK_WINDOW (manager->priv->dialog), _("Set as wallpaper"));
+
+    button = xfce_gtk_button_new_mixed ("gtk-cancel", _("_Cancel"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_CANCEL);
+    gtk_widget_show (button);
+    button = xfce_gtk_button_new_mixed ("gtk-apply", _("_Apply"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_APPLY);
+    gtk_widget_show (button);
+    button = xfce_gtk_button_new_mixed ("gtk-ok", _("_OK"));
+    gtk_dialog_add_action_widget (GTK_DIALOG (manager->priv->dialog), button, GTK_RESPONSE_OK);
+    gtk_widget_show (button);
+
     vbox = gtk_dialog_get_content_area (GTK_DIALOG (manager->priv->dialog));
 
     manager->priv->monitor_chooser = rstto_monitor_chooser_new ();
     manager->priv->style_combo = gtk_combo_box_text_new ();
 
-    gtk_table_set_row_spacings (GTK_TABLE (image_prop_table), 6);
-    gtk_table_set_col_spacings (GTK_TABLE (image_prop_table), 6);
+    gtk_grid_set_row_spacing (GTK_GRID (image_prop_grid), 6);
+    gtk_grid_set_column_spacing (GTK_GRID (image_prop_grid), 6);
 
     for (i = 0; i < n_monitors; ++i)
     {
-        gdk_screen_get_monitor_geometry (
-                screen,
-                i,
+        gdk_monitor_get_geometry (
+                gdk_display_get_monitor (display, i),
                 &monitor_geometry);
         rstto_monitor_chooser_add (
                 RSTTO_MONITOR_CHOOSER (manager->priv->monitor_chooser),
@@ -464,34 +356,27 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             0);
     gtk_box_pack_start (
             GTK_BOX (vbox),
-            image_prop_table,
+            image_prop_grid,
             FALSE,
             FALSE,
             0);
 
-    gtk_table_attach (
-            GTK_TABLE (image_prop_table),
+    gtk_grid_attach (
+            GTK_GRID (image_prop_grid),
             style_label,
             0,
-            1,
             0,
             1,
-            0,
-            0,
-            0,
-            0);
-    gtk_table_attach (
-            GTK_TABLE (image_prop_table),
+            1);
+    gtk_grid_attach (
+            GTK_GRID (image_prop_grid),
             manager->priv->style_combo,
             1,
-            2,
             0,
             1,
-            GTK_EXPAND|GTK_FILL,
-            0,
-            0,
-            0);
+            1);
 
+    gtk_widget_set_hexpand (manager->priv->style_combo, TRUE);
     gtk_combo_box_text_append_text (
             GTK_COMBO_BOX_TEXT (manager->priv->style_combo),
             _("Auto"));
@@ -515,7 +400,8 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
             GTK_COMBO_BOX (manager->priv->style_combo),
             3);
 
-    manager->priv->screen = gdk_screen_get_number (screen);
+    // there's only one screen in GTK3
+    manager->priv->screen = 0;
 
     gtk_window_set_resizable (GTK_WINDOW (manager->priv->dialog), FALSE);
 
@@ -533,17 +419,13 @@ rstto_xfce_wallpaper_manager_init (GObject *object)
     gtk_toggle_button_set_active (
             GTK_TOGGLE_BUTTON (manager->priv->check_button),
             manager->priv->workspace_mode);
-    gtk_table_attach (
-            GTK_TABLE (image_prop_table),
+    gtk_grid_attach (
+            GTK_GRID (image_prop_grid),
             manager->priv->check_button,
             0,
-            2,
             1,
             2,
-            GTK_EXPAND|GTK_FILL,
-            0,
-            0,
-            0);
+            1);
     g_signal_connect (manager->priv->check_button,
             "toggled",
             G_CALLBACK (cb_workspace_mode_changed),
@@ -643,7 +525,7 @@ rstto_get_active_workspace_number (GdkScreen *screen)
     gint       format_ret;
     gint       ws_num = 0;
 
-    gdk_error_trap_push ();
+    gdk_x11_display_error_trap_push (gdk_screen_get_display (screen));
 
     root = gdk_screen_get_root_window (screen);
 
@@ -656,18 +538,18 @@ rstto_get_active_workspace_number (GdkScreen *screen)
             False);
 
     if (XGetWindowProperty (GDK_WINDOW_XDISPLAY (root),
-            gdk_x11_get_default_root_xwindow(),
+            gdk_x11_get_default_root_xwindow (),
             _NET_CURRENT_DESKTOP, 0, 32, False, XA_CARDINAL,
             &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
             (gpointer) &prop_ret) != Success)
     {
         if (XGetWindowProperty (GDK_WINDOW_XDISPLAY (root),
-            gdk_x11_get_default_root_xwindow(),
-            _WIN_WORKSPACE, 0, 32, False, XA_CARDINAL,
-            &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
-            (gpointer) &prop_ret) != Success)
+                gdk_x11_get_default_root_xwindow (),
+                _WIN_WORKSPACE, 0, 32, False, XA_CARDINAL,
+                &type_ret, &format_ret, &nitems_ret, &bytes_after_ret,
+                (gpointer) &prop_ret) != Success)
         {
-          if (G_UNLIKELY (prop_ret != NULL))
+            if (G_UNLIKELY (prop_ret != NULL))
             {
                 XFree (prop_ret);
                 prop_ret = NULL;
@@ -678,16 +560,11 @@ rstto_get_active_workspace_number (GdkScreen *screen)
     if (G_LIKELY (prop_ret != NULL))
     {
         if (G_LIKELY (type_ret != None && format_ret != 0))
-                ws_num = *prop_ret;
+            ws_num = *prop_ret;
         XFree (prop_ret);
     }
 
-#if GTK_CHECK_VERSION (3, 0, 0)
-    gdk_error_trap_pop_ignored ();
-#else
-    if (gdk_error_trap_pop () != 0)
-        return 0;
-#endif
+    gdk_x11_display_error_trap_pop_ignored (gdk_screen_get_display (screen));
 
     return ws_num;
 }
@@ -697,7 +574,6 @@ cb_style_combo_changed (
         GtkComboBox *style_combo,
         RsttoXfceWallpaperManager *manager)
 {
-
     manager->priv->style = gtk_combo_box_get_active (style_combo);
 
     manager->priv->monitor = rstto_monitor_chooser_get_selected (
